#!/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_7bpu2_kz5n/croot/gdal-split_1691162695819/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin/python

import sys

from osgeo.gdal import deprecation_warn

# import osgeo_utils.gdal_proximity as a convenience to use as a script
from osgeo_utils.gdal_proximity import *  # noqa
from osgeo_utils.gdal_proximity import main

deprecation_warn("gdal_proximity")
sys.exit(main(sys.argv))
